@@ -46,6 +46,7 @@ setMethod("radiusMinimaxIC", signature(L2Fam = "L2ParamFamily",
                             warn = warn, verbose = verbose)
                 loRisk <- getAsRisk(risk = risk, L2deriv = L2Fam@L2derivDistr[[1]], 
                                     neighbor = neighbor, biastype = biastype,
+                                    normtype = normtype(risk),
                                     clip = resLo$b, cent = resLo$a, 
                                     stand = resLo$A, trafo = trafo)[[1]]
             }
@@ -54,6 +55,7 @@ setMethod("radiusMinimaxIC", signature(L2Fam = "L2ParamFamily",
                 bmin <- getAsRisk(risk = asBias(biastype = biastype), 
                                   L2deriv = L2Fam@L2derivDistr[[1]], 
                                   neighbor = neighbor, biastype = biastype, 
+                                  normtype = normtype(risk),
                                   trafo = trafo)$asBias
                 upRisk <- bmin^2
             }else{
@@ -65,6 +67,7 @@ setMethod("radiusMinimaxIC", signature(L2Fam = "L2ParamFamily",
                             warn = warn, verbose = verbose)
                 upRisk <- getAsRisk(risk = risk, L2deriv = L2Fam@L2derivDistr[[1]], 
                                     neighbor = neighbor, biastype = biastype, 
+                                    normtype = normtype(risk),
                                     clip = resUp$b, cent = resUp$a, 
                                     stand = resUp$A, trafo = trafo)[[1]]
             }
@@ -152,6 +155,7 @@ setMethod("radiusMinimaxIC", signature(L2Fam = "L2ParamFamily",
                     normtype(riskLo) <- resLo$normtype
                     loRisk <- getAsRisk(risk = riskLo, L2deriv = L2deriv, 
                                         neighbor = neighbor, biastype = biastype, 
+                                        normtype = normtype(risk),
                                         clip = resLo$b, cent = resLo$a, 
                                         stand = resLo$A, trafo = trafo)[[1]]
                     loNorm <- resLo$normtype
@@ -161,6 +165,7 @@ setMethod("radiusMinimaxIC", signature(L2Fam = "L2ParamFamily",
                     biasR <- getAsRisk(risk = asBias(biastype = biastype(risk), 
                                       normtype = normtype), L2deriv = L2deriv, 
                                       neighbor = neighbor, biastype = biastype, 
+                                      normtype = normtype(risk),
                                       Distr = L2Fam@distribution, 
                                       DistrSymm = L2Fam@distrSymm, 
                                       L2derivSymm = L2derivSymm, 
@@ -184,7 +189,8 @@ setMethod("radiusMinimaxIC", signature(L2Fam = "L2ParamFamily",
                     riskUp <- risk
                     normtype(riskUp) <- resUp$normtype
                     upRisk <- getAsRisk(risk = riskUp, L2deriv = L2deriv, neighbor = neighbor, 
-                                biastype = biastype, clip = resUp$b, cent = resUp$a,
+                                biastype = biastype, normtype = normtype(risk),
+                                clip = resUp$b, cent = resUp$a,
                                 stand = resUp$A, trafo = trafo)[[1]]
                     upNorm <- resUp$normtype
                 }
