@@ -153,6 +153,14 @@ RobB1     # show RobB1
 #type:    (uncond.) total variation neighborhood
 #radius:  0.5
 
+#-------------------------------------------------------------------------------
+## OBRE solution
+#-------------------------------------------------------------------------------
+
+system.time(ICA <-  optIC(model=RobB1, risk=asAnscombe(),
+            verbose=TRUE,lower=NULL,upper=10))
+
+
 #-------------------------------------------------------------------------------
 ## MSE solution
 #-------------------------------------------------------------------------------
